@@ -375,11 +375,7 @@ public:
             // of the event handler. We need to lock the event handler here to call
             // finishMessage.
             //
-#if defined(__MINGW32__)
             IceUtil::LockT<T> sync(_mutex);
-#else
-            IceUtil::LockT<typename T> sync(_mutex);
-#endif
             _current.finishMessage();
         }
     }
