@@ -7,6 +7,7 @@
 
 #include <IceUtil/Shared.h>
 #include <IceUtil/Handle.h>
+#include <IceUtil/Exception.h>
 #include <string>
 #include <vector>
 #include <list>
@@ -18,6 +19,29 @@
 namespace Slice
 {
 
+class CompilerException : public ::IceUtil::Exception
+{
+public:
+
+    CompilerException(const char*, int, const std::string&);
+#ifndef ICE_CPP11_COMPILER
+    ~CompilerException() throw();
+#endif
+    virtual std::string ice_id() const;
+    virtual void ice_print(std::ostream&) const;
+#ifndef ICE_CPP11_MAPPING
+    virtual CompilerException* ice_clone() const;
+#endif
+    virtual void ice_throw() const;
+
+    std::string reason() const;
+
+private:
+
+    static const char* _name;
+    const std::string _reason;
+};
+
 #if defined(_WIN32) && !defined(__MINGW32__)
 
 const IceUtil::Int64 Int32Max =  0x7fffffffi64;
@@ -241,6 +265,9 @@ public:
     void warning(WarningCategory, const std::string&, int, const std::string&) const;
     void warning(WarningCategory, const std::string&, const std::string&, const std::string&) const;
 
+    void error(const std::string&, int, const std::string&) const;
+    void error(const std::string&, const std::string&, const std::string&) const;
+
 private:
 
     bool suppressWarning(WarningCategory) const;
@@ -1118,7 +1145,6 @@ private:
 
     Unit(bool, bool, bool, bool, const StringList&);
     static void eraseWhiteSpace(::std::string&);
-    bool checkUndefinedTypes();
 
     bool _ignRedefs;
     bool _all;
