@@ -1365,7 +1365,9 @@ public:
 void
 Client::run(int argc, char** argv)
 {
-    Ice::CommunicatorHolder communicator = initialize(argc, argv);
+    Ice::PropertiesPtr properties = createTestProperties(argc, argv);
+    properties->setProperty("Ice.AcceptClassCycles", "1");
+    Ice::CommunicatorHolder communicator = initialize(argc, argv, properties);
     void allTests(Test::TestHelper*);
     allTests(this);
 }
