@@ -147,6 +147,17 @@ public final class InitialI extends Initial
         return false;
     }
 
+    @Override
+    public void setCycle(Recursive r, Ice.Current current)
+    {
+    }
+
+    @Override
+    public boolean acceptsClassCycles(Ice.Current current)
+    {
+        return true;
+    }
+
     @Override
     public B
     getMB(Ice.Current current)
