@@ -686,6 +686,8 @@ public class AllTests
                     try
                     {
                         server.ice_ping();
+                        IceSSL.ConnectionInfo info = (IceSSL.ConnectionInfo)server.ice_getConnection().getInfo();
+                        test(info.verified);
                     }
                     catch(Ice.LocalException ex)
                     {
@@ -1367,158 +1369,6 @@ public class AllTests
         }
         out.println("ok");
 
-        out.print("testing ciphers... ");
-        out.flush();
-        {
-            //
-            // Configure a server with RSA and DSA certificates.
-            //
-            // First try a client with a DSA certificate.
-            //
-            initData = createClientProps(defaultProperties, defaultDir, defaultHost, "c_dsa_ca1", "cacert1");
-            Ice.Communicator comm = Ice.Util.initialize(args, initData);
-            ServerFactoryPrx fact = ServerFactoryPrxHelper.checkedCast(comm.stringToProxy(factoryRef));
-            test(fact != null);
-            d = createServerProps(defaultProperties, defaultDir, defaultHost, "s_rsa_dsa_ca1", "cacert1");
-            d.put("IceSSL.VerifyPeer", "1");
-            ServerPrx server = fact.createServer(d);
-            try
-            {
-                server.ice_ping();
-            }
-            catch(Ice.LocalException ex)
-            {
-                ex.printStackTrace();
-                test(false);
-            }
-            fact.destroyServer(server);
-            comm.destroy();
-
-            //
-            // Next try a client with an RSA certificate.
-            //
-            initData = createClientProps(defaultProperties, defaultDir, defaultHost, "c_rsa_ca1", "cacert1");
-            comm = Ice.Util.initialize(args, initData);
-            fact = ServerFactoryPrxHelper.checkedCast(comm.stringToProxy(factoryRef));
-            test(fact != null);
-            d = createServerProps(defaultProperties, defaultDir, defaultHost, "s_rsa_dsa_ca1", "cacert1");
-            d.put("IceSSL.VerifyPeer", "1");
-            server = fact.createServer(d);
-            try
-            {
-                server.ice_ping();
-            }
-            catch(Ice.LocalException ex)
-            {
-                ex.printStackTrace();
-                test(false);
-            }
-            fact.destroyServer(server);
-            comm.destroy();
-        }
-        {
-            //
-            // Configure a server with RSA and a client with DSA. This should fail.
-            //
-            initData = createClientProps(defaultProperties, defaultDir, defaultHost, "c_dsa_ca1", "cacert1");
-            initData.properties.setProperty("IceSSL.Ciphers", "NONE (.*DSS.*)");
-            Ice.Communicator comm = Ice.Util.initialize(args, initData);
-            ServerFactoryPrx fact = ServerFactoryPrxHelper.checkedCast(comm.stringToProxy(factoryRef));
-            test(fact != null);
-            d = createServerProps(defaultProperties, defaultDir, defaultHost, "s_rsa_ca1", "cacert1");
-            d.put("IceSSL.VerifyPeer", "2");
-            ServerPrx server = fact.createServer(d);
-            try
-            {
-                server.ice_ping();
-                test(false);
-            }
-            catch(Ice.SecurityException ex)
-            {
-                // Expected.
-            }
-            catch(Ice.ConnectionLostException ex)
-            {
-                // Expected for thread pool.
-            }
-            catch(Ice.LocalException ex)
-            {
-                ex.printStackTrace();
-                test(false);
-            }
-            fact.destroyServer(server);
-            comm.destroy();
-        }
-        {
-            //
-            // Configure the server with both RSA and DSA certificates, but use the
-            // Alias property to select the RSA certificate. This should fail.
-            //
-            initData = createClientProps(defaultProperties, defaultDir, defaultHost, "c_dsa_ca1", "cacert1");
-            initData.properties.setProperty("IceSSL.Ciphers", "NONE (.*DSS.*)");
-            Ice.Communicator comm = Ice.Util.initialize(args, initData);
-            ServerFactoryPrx fact = ServerFactoryPrxHelper.checkedCast(comm.stringToProxy(factoryRef));
-            test(fact != null);
-            d = createServerProps(defaultProperties, defaultDir, defaultHost, "s_rsa_dsa_ca1", "cacert1");
-            d.put("IceSSL.Alias", "rsacert");
-            d.put("IceSSL.VerifyPeer", "2");
-            ServerPrx server = fact.createServer(d);
-            try
-            {
-                server.ice_ping();
-                test(false);
-            }
-            catch(Ice.SecurityException ex)
-            {
-                // Expected.
-            }
-            catch(Ice.ConnectionLostException ex)
-            {
-                // Expected for thread pool.
-            }
-            catch(Ice.LocalException ex)
-            {
-                ex.printStackTrace();
-                test(false);
-            }
-            fact.destroyServer(server);
-            comm.destroy();
-        }
-        {
-            //
-            // Configure the server with both RSA and DSA certificates, but use the
-            // Alias property to select the DSA certificate. This should succeed.
-            //
-            initData = createClientProps(defaultProperties, defaultDir, defaultHost, "cacert1", "");
-            Ice.Communicator comm = Ice.Util.initialize(args, initData);
-            ServerFactoryPrx fact = ServerFactoryPrxHelper.checkedCast(comm.stringToProxy(factoryRef));
-            test(fact != null);
-            d = createServerProps(defaultProperties, defaultDir, defaultHost, "s_rsa_dsa_ca1", "cacert1");
-            d.put("IceSSL.Alias", "dsacert");
-            d.put("IceSSL.VerifyPeer", "1");
-            // TLS 1.3 no longer supports DSA so disable TLS 1.3 for this test.
-            d.put("IceSSL.Protocols", "ssl3, tls1_0, tls1_1, tls1_2");
-            ServerPrx server = fact.createServer(d);
-            try
-            {
-                server.ice_ping();
-                //
-                // RSA is used by default, so we examine the negotiated cipher to determine whether
-                // DSA was actually used.
-                //
-                IceSSL.ConnectionInfo info = (IceSSL.ConnectionInfo)server.ice_getConnection().getInfo();
-                test(info.cipher.toLowerCase().contains("dss"));
-            }
-            catch(Ice.LocalException ex)
-            {
-                ex.printStackTrace();
-                test(false);
-            }
-            fact.destroyServer(server);
-            comm.destroy();
-        }
-        out.println("ok");
-
         out.print("testing IceSSL.TrustOnly... ");
         out.flush();
         {
@@ -2250,7 +2100,7 @@ public class AllTests
             initData.properties.setProperty("IceSSL.VerifyDepthMax", "4");
             initData.properties.setProperty("Ice.Override.Timeout", "5000"); // 5s timeout
             Ice.Communicator comm = Ice.Util.initialize(initData);
-            Ice.ObjectPrx p = comm.stringToProxy("dummy:wss -h demo.zeroc.com -p 5064");
+            Ice.ObjectPrx p = comm.stringToProxy("dummy:wss -p 443 -h zeroc.com -r /demo-proxy/chat/glacier2");
             while(true)
             {
                 try
@@ -2297,7 +2147,7 @@ public class AllTests
             initData.properties.setProperty("Ice.Override.Timeout", "5000"); // 5s timeout
             initData.properties.setProperty("IceSSL.UsePlatformCAs", "1");
             comm = Ice.Util.initialize(initData);
-            p = comm.stringToProxy("dummy:wss -h demo.zeroc.com -p 5064");
+            p = comm.stringToProxy("dummy:wss -p 443 -h zeroc.com -r /demo-proxy/chat/glacier2");
             while(true)
             {
                 try
