@@ -435,6 +435,24 @@ public class AllTests
         }
         out.println("ok");
 
+        out.print("testing sending class cycle... ");
+        out.flush();
+        {
+            Recursive rec = new Recursive();
+            rec.v = rec;
+            boolean acceptsCycles = initial.acceptsClassCycles();
+            try
+            {
+                initial.setCycle(rec);
+                test(acceptsCycles);
+            }
+            catch(com.zeroc.Ice.UnknownLocalException ex)
+            {
+                test(!acceptsCycles);
+            }
+        }
+        out.println("ok");
+
         return initial;
     }
 }
