@@ -7,7 +7,7 @@
     const Ice = require("ice").Ice;
     const test = require("TestHelper").TestHelper.test;
 
-    async function run(communicator, prx, Test, bidir, helper)
+    async function run(communicator, prx, Test, M, bidir, helper)
     {
         const literals = await prx.opStringLiterals();
 
@@ -1472,6 +1472,12 @@
             }
             await prx.opDoubleMarshaling(1278312346.0 / 13.0, ds);
         }
+
+        {
+            const b = M.BPrx.uncheckedCast(communicator.stringToProxy("b:" + helper.getTestEndpoint()));
+            await b.opB();
+            await b.opIntf();
+        }
     }
 
     exports.Twoways = {run: run};
