@@ -108,6 +108,9 @@
             test(b1.ice_getIdentity().name === "test" && b1.ice_getIdentity().category === "category" &&
                  b1.ice_getAdapterId().length === 0);
 
+            b1 = communicator.stringToProxy("test:tcp --sourceAddress \"::1\"");
+            test(b1.equals(communicator.stringToProxy(b1.toString())));
+
             b1 = communicator.stringToProxy("");
             test(b1 === null);
             b1 = communicator.stringToProxy("\"\"");
@@ -722,6 +725,8 @@
             test(cl.equals(base));
             test(derived.equals(base));
             test(cl.equals(derived));
+            let f = await Test.MyDerivedClassPrx.checkedCast(cl, "facet");
+            test(f === null);
             out.writeLine("ok");
 
             out.write("testing checked cast with context... ");
@@ -740,6 +745,8 @@
                 const connection = await cl.ice_getConnection();
                 if(connection !== null)
                 {
+                    test(!cl.ice_isFixed());
+                    test(cl.ice_fixed(connection).ice_isFixed());
                     await cl.ice_fixed(connection).getContext();
                     test(cl.ice_secure(true).ice_fixed(connection).ice_isSecure());
                     test(cl.ice_facet("facet").ice_fixed(connection).ice_getFacet() == "facet");
