@@ -204,7 +204,7 @@ classdef EncapsDecoder11 < IceInternal.EncapsDecoder
                 % that not all instance references were read if they are from
                 % unknown optional data members.
                 %
-                if length(indirectionTable) == 0
+                if isempty(indirectionTable)
                     throw(Ice.MarshalException('', '', 'empty indirection table'));
                 end
                 if isempty(obj.current.indirectPatchList) && ...
@@ -455,6 +455,7 @@ classdef EncapsDecoder11 < IceInternal.EncapsDecoder
         function r = readSlicedData(obj)
             if isempty(obj.current.slices) % No preserved slices.
                 r = [];
+                return;
             end
 
             %
@@ -483,14 +484,14 @@ classdef EncapsDecoder11 < IceInternal.EncapsDecoder
             r = Ice.SlicedData(obj.current.slices); % Makes a shallow copy
         end
 
-        function r = resolveCompactId(obj, id)
+        function r = resolveCompactId(~, id)
             type = '';
 
             if isempty(type)
                 prop = sprintf('IceCompactId.TypeId_%d.typeId', id);
                 try
                     type = eval(prop);
-                catch ex
+                catch
                 end
             end
 
