@@ -286,6 +286,9 @@ communicatorInit(CommunicatorObject* self, PyObject* args, PyObject* /*kwds*/)
 
     data.compactIdResolver = new IdResolver;
 
+    // Always accept cycles in Python
+    data.properties->setProperty("Ice.AcceptClassCycles", "1");
+
     Ice::CommunicatorPtr communicator;
     try
     {
