@@ -14,6 +14,7 @@ if sys.version_info >= (3, 5):
 else:
     from TestAMDI import MyDerivedClassI
 
+from TestAMDI import BI
 
 from TestHelper import TestHelper
 TestHelper.loadSlice("Test.ice")
@@ -35,5 +36,6 @@ class ServerAMD(TestHelper):
             communicator.getProperties().setProperty("TestAdapter.Endpoints", self.getTestEndpoint())
             adapter = communicator.createObjectAdapter("TestAdapter")
             adapter.add(MyDerivedClassI(), Ice.stringToIdentity("test"))
+            adapter.add(BI(), Ice.stringToIdentity("b"))
             adapter.activate()
             communicator.waitForShutdown()
